@@ -2,20 +2,21 @@
 
 import logging
 import uuid
-from teaspoons_client import (
-    PipelineRunsApi,
-    PreparePipelineRunResponse,
-    PreparePipelineRunRequestBody,
-    StartPipelineRunRequestBody,
-    JobControl,
+from typing import Any
+
+from teaspoons_client import (  # type: ignore[attr-defined]
     AsyncPipelineRunResponse,
+    JobControl,
     PipelineRun,
+    PipelineRunsApi,
+    PreparePipelineRunRequestBody,
+    PreparePipelineRunResponse,
+    StartPipelineRunRequestBody,
 )
 
-from terralab.utils import upload_file_with_signed_url, download_files_with_signed_urls
 from terralab.client import ClientWrapper
-from terralab.log import indented
-
+from terralab.log import indented, add_blankline_before
+from terralab.utils import upload_file_with_signed_url, download_files_with_signed_urls
 
 LOGGER = logging.getLogger(__name__)
 
@@ -28,15 +29,15 @@ def prepare_pipeline_run(
     pipeline_name: str,
     job_id: str,
     pipeline_version: int,
-    pipeline_inputs: dict,
+    pipeline_inputs: dict[str, Any],
     description: str,
-) -> dict:
+) -> dict[str, str]:
     """Call the preparePipelineRun Teaspoons endpoint.
     Return a dictionary of {input_name: signed_url}."""
     prepare_pipeline_run_request_body: PreparePipelineRunRequestBody = (
         PreparePipelineRunRequestBody(
             jobId=job_id,
-            pipeline_name=pipeline_name,
+            pipelineName=pipeline_name,
             pipelineVersion=pipeline_version,
             pipelineInputs=pipeline_inputs,
             description=description,
@@ -50,13 +51,14 @@ def prepare_pipeline_run(
         )
 
         result = response.file_input_upload_urls
+
         return {
-            input_name: signed_url_dict.get(SIGNED_URL_KEY)
+            input_name: signed_url_dict[SIGNED_URL_KEY]
             for input_name, signed_url_dict in result.items()
         }
 
 
-def start_pipeline_run(job_id: str) -> uuid.UUID:
+def start_pipeline_run(job_id: str) -> str:
     """Call the startPipelineRun Teaspoons endpoint and return the Async Job Response."""
     start_pipeline_run_request_body: StartPipelineRunRequestBody = (
         StartPipelineRunRequestBody(jobControl=JobControl(id=job_id))
@@ -89,8 +91,8 @@ def get_pipeline_runs(n_results_requested: int) -> list[PipelineRun]:
         response = pipeline_runs_client.get_all_pipeline_runs(
             limit=min(api_chunk_default, n_results_requested), page_token=None
         )
-        LOGGER.debug(f"Retrieved {len(response.results)} PipelineRun results")
-        results = response.results
+        results = list(response.results) if response.results else []
+        LOGGER.debug(f"Retrieved {len(results)} PipelineRun results")
         page_token = response.page_token
 
         while len(results) < n_results_requested and page_token:
@@ -98,9 +100,10 @@ def get_pipeline_runs(n_results_requested: int) -> list[PipelineRun]:
                 limit=min(api_chunk_default, n_results_requested - len(results)),
                 page_token=page_token,
             )
-            results.extend(response.results)
+            new_results = list(response.results) if response.results else []
+            results.extend(new_results)
             LOGGER.debug(
-                f"Retrieved {len(response.results)} PipelineRun more results, totaling {len(results)}"
+                f"Retrieved {len(new_results)} PipelineRun more results, totaling {len(results)}"
             )
             page_token = response.page_token
             if not (page_token):
@@ -113,15 +116,18 @@ def get_pipeline_runs(n_results_requested: int) -> list[PipelineRun]:
 
 
 def prepare_upload_start_pipeline_run(
-    pipeline_name: str, pipeline_version: int, pipeline_inputs: dict, description: str
-) -> uuid.UUID:
+    pipeline_name: str,
+    pipeline_version: int,
+    pipeline_inputs: dict[str, Any],
+    description: str,
+) -> str:
     """Prepare pipeline run, upload input files, and start pipeline run.
     Returns the uuid of the job."""
     # generate a job id for the user
     job_id = str(uuid.uuid4())
     LOGGER.info(f"Generated job_id {job_id}")
 
-    file_input_upload_urls: dict = prepare_pipeline_run(
+    file_input_upload_urls: dict[str, str] = prepare_pipeline_run(
         pipeline_name, job_id, pipeline_version, pipeline_inputs, description
     )
 
@@ -144,7 +150,7 @@ def prepare_upload_start_pipeline_run(
 
 def get_result_and_download_pipeline_run_outputs(
     job_id: uuid.UUID, local_destination: str
-):
+) -> None:
     """Retrieve pipeline run result, download all output files."""
     LOGGER.info(
         f"Getting results for job {job_id} and downloading to {local_destination}"
@@ -153,7 +159,19 @@ def get_result_and_download_pipeline_run_outputs(
     job_status: str = result.job_report.status
     LOGGER.debug(f"Job {job_id} status is {job_status}")
     if job_status != "SUCCEEDED":
-        LOGGER.error(f"Results not available for job {job_id} with status {job_status}")
+        LOGGER.error(
+            add_blankline_before(
+                f"Results not available for job {job_id} with status {job_status}"
+            )
+        )
+        exit(1)
+
+    if not result.pipeline_run_report.outputs:
+        LOGGER.error(
+            add_blankline_before(
+                f"Results for job {job_id} have expired. No results available."
+            )
+        )
         exit(1)
 
     # extract output signed urls and download them all
